traitsui\.tests\.null\_backend\.test\_font\_trait module
========================================================

.. automodule:: traitsui.tests.null_backend.test_font_trait
    :members:
    :undoc-members:
    :show-inheritance:
